@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Fields.py,v 1.9 1999/08/18 14:05:16 gobry Exp $
+# $Id: Fields.py,v 1.10 1999/08/25 11:07:31 gobry Exp $
 
 import string, types, re, string
 
@@ -80,8 +80,21 @@ class Author (Access):
             else:
                 self.last  = copy
                 self.first = None
+
+            # cleanup
+            if self.last == '': self.last = None
+            if self.first == '': self.first = None
         else:
             if copy:
+                def clean_entry (f):
+                    if f is not None:
+                        f = string.strip (f)
+                        if f == '': f = None
+
+                    return f
+                
+                copy = map (clean_entry, copy)
+
                 self.honorific = copy [0]
                 self.first     = copy [1]
                 self.last      = copy [2]
@@ -113,7 +126,8 @@ class Author (Access):
         return self.text
 
     def __repr__ (self):
-        return str (self)
+        return "Author ((%s, %s, %s, %s))" % (self.honorific, self.first,
+                                              self.last, self.lineage)
 
 
     def match (self, regex):
@@ -307,7 +321,7 @@ class Text (Access):
 
 
     def __repr__ (self):
-        return `self.text`
+        return "Text (%s)" % `self.text`
 
 
     def match (self, regex):
