@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Pybliographic.py,v 1.11 1999/08/18 14:05:33 gobry Exp $
+# $Id: Pybliographic.py,v 1.13 1999/08/25 11:07:35 gobry Exp $
 
 import string, os
 
@@ -33,16 +33,6 @@ from Pyblio.GnomeUI.Database import *
 from Pyblio.GnomeUI.Entry  import *
 from Pyblio.GnomeUI.Search import *
     
-def popup_add (menu, item, action = None, argument = None):
-    """ Helper to add a new menu entry """
-    tmp = GtkMenuItem (item)
-    if action:
-        tmp.connect ("activate", action, argument)
-    tmp.show ()
-    menu.append (tmp)
-    
-    return tmp
-
 
 class URLFileSelection (GtkFileSelection):
     """ Extended file selection dialog, with an URL field and a type
@@ -86,10 +76,10 @@ class URLFileSelection (GtkFileSelection):
         menu = GtkMenu ()
         self.menu.set_menu (menu)
         if has_auto:
-            popup_add (menu, " - Auto - ", self.menu_select, None)
+            Utils.popup_add (menu, " - Auto - ", self.menu_select, None)
 
         for avail in Open.available ():
-            popup_add (menu, avail, self.menu_select, avail)
+            Utils.popup_add (menu, avail, self.menu_select, avail)
             
         self.menu.set_history (0)
         self.type = None
@@ -123,13 +113,14 @@ class URLFileSelection (GtkFileSelection):
 class Pybliographic (GnomeApp):
     """ Main Class defining a Pybliographic window """
     
-    def __init__ (self):
+    def __init__ (self, version = '0.0'):
         GnomeApp.__init__ (self, "Pybliographer", "Pybliographer")
 
         self.connect ("destroy", self.quit)
         self.connect ("delete_event", self.quit)
 
         self.set_title("Pybliographic")
+        self.version = version
         
         self.main_box = GtkVBox()
         self.set_contents (self.main_box)
@@ -234,15 +225,15 @@ class Pybliographic (GnomeApp):
         # Le popup menu
         self.menu = GtkMenu ()
         self.menu_item = {}
-        self.menu_item ['add']    = popup_add (self.menu, "New...",  self.edit_new)
-        self.menu_item ['edit']   = popup_add (self.menu, "Edit...", self.edit_entry)
-        self.menu_item ['remove'] = popup_add (self.menu, "Delete",  self.edit_delete)
+        self.menu_item ['add']    = \
+                       popup_add (self.menu, "New...",  self.edit_new)
+        self.menu_item ['edit']   = \
+                       popup_add (self.menu, "Edit...", self.edit_entry)
+        self.menu_item ['remove'] = \
+                       popup_add (self.menu, "Delete",  self.edit_delete)
         self.menu.show ()
 
-        colormap = self.get_colormap ()
-        self.color = {}
-        self.color ['red'] = colormap.alloc ("red")
-        self.color ['blue'] = colormap.alloc ("blue")
+        Utils.init_colors (self.get_colormap ())
 
         self.directory = './'
         self.modified  = 0
@@ -271,24 +262,7 @@ class Pybliographic (GnomeApp):
             self.database.set (Open.bibnew (file, type))
             
         except IOError, err:
-            
-            dialog = GnomeDialog ('Creation Error', STOCK_BUTTON_CLOSE)
-            dialog.button_connect (1, GnomeDialog.close)
-            dialog.set_usize (500, 300)
-            
-            text = GtkText ()
-            text.insert (None, None, None,
-                         "While creating, the following errors occured:\n\n")
-            text.insert (None, self.color ['red'], None, str (err))
-
-            holder = GtkScrolledWindow ()
-            holder.set_policy (POLICY_AUTOMATIC, POLICY_AUTOMATIC)
-            holder.add (text)
-
-            dialog.vbox.pack_start (holder)
-            
-            dialog.show_all ()
-            dialog.run_and_close ()
+            Utils.error_dialog ('Creation error', err)
             return
 
         self.status.pop (1)
@@ -309,24 +283,8 @@ class Pybliographic (GnomeApp):
             
         except IOError, err:
             Utils.set_cursor (self, 'normal')
-            
-            dialog = GnomeDialog ('Open Error', STOCK_BUTTON_CLOSE)
-            dialog.button_connect (1, GnomeDialog.close)
-            dialog.set_usize (500, 300)
-            
-            text = GtkText ()
-            text.insert (None, None, None,
-                         "While opening, the following errors occured:\n\n")
-            text.insert (None, self.color ['red'], None, str (err))
 
-            holder = GtkScrolledWindow ()
-            holder.set_policy (POLICY_AUTOMATIC, POLICY_AUTOMATIC)
-            holder.add (text)
-
-            dialog.vbox.pack_start (holder)
-            
-            dialog.show_all ()
-            dialog.run_and_close ()
+            Utils.error_dialog ('Open Error', err)
             return
 
         self.status.pop (1)
@@ -355,7 +313,8 @@ class Pybliographic (GnomeApp):
             return
 
         if self.modified:
-            d = GnomeQuestionDialog ("Database is modified. Quit without saving ?", callback)
+            d = GnomeQuestionDialog ("Database is modified.\n" +
+                                     "Quit without saving ?", callback)
             d.run_and_close ()
             
         if not self.modified: self.quit ()
@@ -372,7 +331,8 @@ class Pybliographic (GnomeApp):
             self.modified = 0
             
         except IOError, err:
-            GnomeErrorDialog ("can't save file: %s" % str (err)).run_and_close ()
+            d = GnomeErrorDialog ("can't save file: %s" % str (err))
+            d.run_and_close ()
         return
     
     # --------------------------------------------------
@@ -410,14 +370,18 @@ class Pybliographic (GnomeApp):
 
     def edit_new (self, *arg):
         selection = self.database.selection
+
+        if not self.database.data.has_property ('add'):
+            d = GnomeErrorDialog ("edition is disabled in this database", self)
+            d.run_and_close ()
+            return
         
         if not selection: 
             row = 0
         else:
             row = self.database.selected_rows () [0]
 
-        entbase = Config.get ("base/entries").data.values () [0]
-        entry = Base.Entry (Base.Key (self.database.data, ''), '', entbase)
+        entry = self.database.data.new_entry ()
         
         def callback (entry, self, selection = row):
             self.status.pop (1)
@@ -438,6 +402,12 @@ class Pybliographic (GnomeApp):
         selection = self.database.selection
         if not selection: return
 
+        # if we have no right to edit
+        if not self.database.data.has_property ('edit'): 
+            d = GnomeErrorDialog ("edition is disabled in this database")
+            d.run_and_close ()
+            return
+
         row = self.database.selected_rows () [0]
         e = selection [0]
         
@@ -459,13 +429,19 @@ class Pybliographic (GnomeApp):
         selection = self.database.selection
         if not selection: return
 
+        if not self.database.data.has_property ('remove'): 
+            d = GnomeErrorDialog ("edition is disabled in this database", self)
+            d.run_and_close ()
+            return
+
         entry = selection [0]
         self.__ans = 0
         def callback (arg, self = self):
             if arg == 0: self.__ans = 1
             return
 
-        d = GnomeQuestionDialog ("Really remove entry %s ?" % (entry.name), callback)
+        d = GnomeQuestionDialog ("Really remove entry %s ?" %
+                                 (entry.name), callback)
         d.run_and_close ()
 
         if self.__ans:
@@ -488,17 +464,20 @@ class Pybliographic (GnomeApp):
         if self.database.data is None: return
         
         if (event.type == GDK._2BUTTON_PRESS and event.button == 1):
-            if not self.database.data.properties ['edit']: return
-            
             # Always select the item below the cursor
             couple = self.database.get_selection_info (event.x, event.y)
             if couple:
                 self.database.select_row (couple [0], couple [1])
-                self.edit_entry (arg)
-            
+                if not self.database.data.has_property ('edit'): return
+
+                # else, do as if the Edit menu as been activated
+                self.menu_item ['edit'].emit ("activate", None)
+                return
+        
         if (event.type == GDK.BUTTON_PRESS and event.button == 3):
             for f in ('add', 'edit', 'remove'):
-                self.menu_item [f].set_sensitive (self.database.data.properties [f])
+                self.menu_item [f].set_sensitive \
+                               (self.database.data.has_property (f))
             
             # Always select the item below the cursor
             couple = self.database.get_selection_info (event.x, event.y)
@@ -518,11 +497,11 @@ class Pybliographic (GnomeApp):
             
             # Display this entry
             self.display.freeze ()
-            self.display.delete_text (0, self.display.get_point ())
+            self.display.delete_text (0, -1)
 
             entry = e.type
                 
-            self.display.insert (None, self.color['blue'], None, entry.name)
+            self.display.insert (None, Utils.color['blue'], None, entry.name)
             self.display.insert_defaults (" ["+ str (e.name) + "]\n\n")
             
             dico = e.keys ()
@@ -538,7 +517,7 @@ class Pybliographic (GnomeApp):
                 
 		if e.has_key (field):
                     sp = ' ' * (mlen - len (f.name))
-                    self.display.insert (None, self.color ['red'], None,
+                    self.display.insert (None, Utils.color ['red'], None,
                                          f.name + ": " + sp)
                     self.display.insert_defaults (str (e [field]) + "\n")
                     dico.remove (field)
@@ -548,7 +527,7 @@ class Pybliographic (GnomeApp):
             
             for f in dico:
                 sp = ' ' * (mlen - len (f))
-                self.display.insert (None, self.color['red'], None,
+                self.display.insert (None, Utils.color['red'], None,
                                      f + ": " + sp)
                 self.display.insert_defaults (str (e [f]) + "\n")
 
@@ -558,7 +537,7 @@ class Pybliographic (GnomeApp):
     # --------------------------------------------------
 
     def help_about (self, *arg):
-        GnomeAbout('Pybliographic', '0.0',
+        GnomeAbout('Pybliographic', self.version,
                    'This program is copyrighted under the GNU GPL',
                    ['Frdric Gobry'],
                    'Gnome interface to the Pybliographer system').show()
