@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Open.py,v 1.12 1999/08/18 14:05:16 gobry Exp $
+# $Id: Open.py,v 1.14 1999/08/25 11:07:31 gobry Exp $
 
 
 from types import *
@@ -93,7 +93,7 @@ def bibopen (entity, how = None):
 				opener = get (method, 'open')
 				if opener:
 					base = opener (url, 1)
-					if base: break
+					if base is not None: break
 		else:
 			opener = get (how, 'open')
 			if opener:
@@ -120,14 +120,14 @@ def bibopen (entity, how = None):
 	base = simple_try (url, how)
 	
 	# If one don't know how to retrieve a remote file, do it
-	if base == None and (url [0] == 'http' or url [0] == 'ftp'):
+	if base is None and (url [0] == 'http' or url [0] == 'ftp'):
 		file, header = urllib.urlretrieve (entity)
 
 		url = ['file', '', file, '', '', '']
 
 		base = simple_try (url, how)
 		
-	if base == None:
+	if base is None:
 		raise IOError, "don't know how to open `" + entity + "'"
     
 	return base
