@@ -18,9 +18,13 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: accents.c,v 1.7 1999/07/16 13:26:55 gobry Exp $
+ $Id: accents.c,v 1.8 1999/08/04 09:37:20 gobry Exp $
 */
 
+#ifdef HAVE_CONFIG_H
+#include "pyblioconf.h"
+#endif
+
 #include <ctype.h>
 #include "bibtex.h"
 
@@ -30,6 +34,12 @@ typedef struct  {
 }
 CharMapping;
 
+typedef struct  {
+    gchar * c;
+    gchar * m;
+}
+StringMapping;
+
 CharMapping acute [] = {
     {'A', ''},
     {'E', ''},
@@ -95,6 +105,10 @@ CharMapping cedilla [] = {
     {0, 0}
 };
 
+StringMapping commands [] = {
+    {"backslash", "\\"},
+    {NULL, NULL}
+};
 
 static gchar *
 initialize_table (CharMapping * map) {
@@ -112,6 +126,20 @@ initialize_table (CharMapping * map) {
     return table;
 }
 
+static GHashTable *
+initialize_mapping (StringMapping * map) {
+    GHashTable * dico;
+    
+    dico = g_hash_table_new (g_str_hash, g_str_equal);
+    
+    while (map->c != NULL) {
+	g_hash_table_insert (dico, map->c, map->m);
+	map ++;
+    }
+
+    return dico;
+}
+
 static gchar *
 eat_as_string (GList ** flow,
 	       gint qtt,
@@ -155,6 +183,7 @@ bibtex_accent_string (BibtexStruct * s,
     static gchar * hat_table = NULL;
     static gchar * trema_table = NULL;
     static gchar * cedilla_table = NULL;
+    static GHashTable * commands_table = NULL;
 
     gchar * text, * tmp, accent;
 
@@ -164,11 +193,13 @@ bibtex_accent_string (BibtexStruct * s,
     if (acute_table == NULL) {
 	/* Initialize accent table if necessary */
 
-	acute_table   = initialize_table (acute);
-	grave_table   = initialize_table (grave);
-	hat_table     = initialize_table (hat);
-	trema_table   = initialize_table (trema);
-	cedilla_table = initialize_table (cedilla);
+	acute_table    = initialize_table   (acute);
+	grave_table    = initialize_table   (grave);
+	hat_table      = initialize_table   (hat);
+	trema_table    = initialize_table   (trema);
+	cedilla_table  = initialize_table   (cedilla);
+
+	commands_table = initialize_mapping (commands);
     }
 
     /* traiter les codes de 1 de long */
@@ -228,6 +259,14 @@ bibtex_accent_string (BibtexStruct * s,
 	    }
 	}
     }
+    else {
+	/* long command, use dictionnary to eventually map */
+	text = g_hash_table_lookup (commands_table, s->value.com);
+
+	if (text) {
+	    return g_strdup (text);
+	}
+    }
 
     if (loss) * loss = TRUE;
     bibtex_warning ("unable to convert `\\%s'", s->value.com);
