@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtexmodule.c,v 1.5 1999/08/18 14:06:10 gobry Exp $
+ $Id: bibtexmodule.c,v 1.6 1999/08/25 11:07:37 gobry Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -255,14 +255,14 @@ bib_expand (PyObject * self, PyObject * args) {
 }
 
 static PyObject *
-bib_native (PyObject * self, PyObject * args) {
+bib_get_native (PyObject * self, PyObject * args) {
     PyObject * tmp;
     BibtexField * field;
     PyBibtexField_Object * field_obj;
     gchar * text;
     int i;
 
-    if (! PyArg_ParseTuple(args, "O!:native", & PyBibtexField_Type, & field_obj))
+    if (! PyArg_ParseTuple(args, "O!:get_native", & PyBibtexField_Type, & field_obj))
 	return NULL;
 
     field = field_obj->obj;
@@ -274,6 +274,52 @@ bib_native (PyObject * self, PyObject * args) {
     return tmp;
 }
 
+static PyObject *
+bib_set_native (PyObject * self, PyObject * args) {
+    PyObject * tmp;
+    BibtexField * field;
+    static BibtexSource * source = NULL;
+    BibtexEntry * entry;
+    BibtexStruct * s;
+    BibtexFieldType type;
+
+    PyBibtexField_Object * field_obj;
+    gchar * text, * to_parse;
+    int i;
+
+    if (! PyArg_ParseTuple(args, "si:set_native", & text, &type))
+	return NULL;
+
+    /* Create new source */
+    if (source == NULL) source = bibtex_source_new ();
+
+    /* parse as a string */
+    to_parse = g_strdup_printf ("@preamble{%s}", text);
+
+    if (! bibtex_source_string (source, "internal string", to_parse)) {
+	PyErr_SetString (PyExc_IOError, "can't create internal string");
+	return NULL;
+    }
+
+    g_free (to_parse);
+
+    entry = bibtex_source_next_entry (source, FALSE);
+
+    if (entry == NULL) {
+	return NULL;
+    }
+
+    s = bibtex_struct_copy (entry->preamble);
+    bibtex_entry_destroy (entry, TRUE);
+
+    field = bibtex_struct_as_field (s, type);
+
+    tmp = (PyObject *) PyObject_NEW (PyBibtexField_Object, & PyBibtexField_Type);
+    ((PyBibtexField_Object *) tmp)->obj = field;
+
+    return tmp;
+}
+
 
 static void 
 fill_dico (gpointer key, gpointer value, gpointer user)
@@ -321,7 +367,7 @@ bib_next (PyObject * self, PyObject * args)
 
     PyObject * dico, * tmp, * tmp2;
 
-    if (! PyArg_ParseTuple(args, "O!:next", &PyBibtexSource_Type, & file_obj))
+    if (! PyArg_ParseTuple(args, "O!:next", & PyBibtexSource_Type, & file_obj))
 	return NULL;
 
     file = file_obj->obj;
@@ -546,7 +592,8 @@ static PyMethodDef bibtexMeth [] = {
     { "set_offset", bib_set_offset, METH_VARARGS },
     { "get_offset", bib_get_offset, METH_VARARGS },
     { "expand", bib_expand, METH_VARARGS },
-    { "native", bib_native, METH_VARARGS },
+    { "get_native", bib_get_native, METH_VARARGS },
+    { "set_native", bib_set_native, METH_VARARGS },
     { "reverse", bib_reverse, METH_VARARGS },
     { "get_dict", bib_get_dict, METH_VARARGS },
     {NULL, NULL, 0},
