@@ -19,12 +19,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybliographic.py,v 1.1 1999/08/16 09:38:34 gobry Exp $
+# $Id: pybliographic.py,v 1.2 1999/08/25 11:07:40 gobry Exp $
 
 
-from Pyblio.GnomeUI.Pybliographic import *
+from Pyblio.GnomeUI import Pybliographic
+from gtk import *
 
-main = Pybliographic ()
+main = Pybliographic.Pybliographic (version)
 main.show ()
 
 if len (sys.argv) > 1:
